==> benchmarks-0.3.tar.gz: benchmarks-0.3/tile/cyc-bzero/tile.h <==
/*
 * Copyright (c) 1994
 *      The Regents of the University of California.  All rights reserved.
 *
 * This code is derived from software contributed to Berkeley by
 * Marti Hearst.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */

#include <sys/types.h>

/*
 * A text tile is identified by its start and end offset
 * in the document.
 */
typedef struct _tile {
	off_t startoff;
	off_t endoff;
} TILE;

/*
 * A tileized file is returned by the tile() return in the
 * form of a count of the tiles and an array of tile offsets.
 * The structure is returned in malloced space and must be
 * freed by the caller.
 */
typedef struct _tiledoc {
  	long numtiles;
	TILE ?tilearray;
} TILEDOC;

extern void freetiledoc(TILEDOC *);

/*
 * Tweakable Parameters (externed in tile.h)
 */
extern int     bound;
extern int     numiter;
extern int     this_k;
extern int     word_sep_num;
extern int     use_stop_list;
extern int     not_para_boundaries;
extern int     verbose;
extern int     indented;	/* consider an indented line a paragraph */

extern TILEDOC *
tile(mstring_t, void (*)(int, mstring_t, long));

==> benchmarks-1.0.tar.gz: benchmarks-1.0/tile/cyc-bzero/tile.h <==
/*
 * Copyright (c) 1994
 *      The Regents of the University of California.  All rights reserved.
 *
 * This code is derived from software contributed to Berkeley by
 * Marti Hearst.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */

#include <sys/types.h>

/*
 * A text tile is identified by its start and end offset
 * in the document.
 */
typedef struct _tile {
	off_t startoff;
	off_t endoff;
} TILE;

/*
 * A tileized file is returned by the tile() return in the
 * form of a count of the tiles and an array of tile offsets.
 * The structure is returned in malloced space and must be
 * freed by the caller.
 */
typedef struct _tiledoc {
  	long numtiles;
	TILE ?tilearray;
} TILEDOC;

extern void freetiledoc(TILEDOC *);

/*
 * Tweakable Parameters (externed in tile.h)
 */
extern int     bound;
extern int     numiter;
extern int     this_k;
extern int     word_sep_num;
extern int     use_stop_list;
extern int     not_para_boundaries;
extern int     verbose;
extern int     indented;	/* consider an indented line a paragraph */

extern TILEDOC *
tile(mstring_t, void (*)(int, mstring_t<`r+`H>, long));
